@@ -205,7 +205,9 @@ bool BackendKicker::selectLeague(QString league)
     if (league == "1. Bundesliga") {
         m_URL = "http://www.kicker.de/news/fussball/bundesliga/spieltag/1-bundesliga/2010-11/spieltag.html";
     } else if (league == "2. Bundesliga") {
-        m_URL = "http://www.kicker.de/news/fussball/bundesliga/spieltag/2-bundesliga/2010-11/spieltag.html";
+        m_URL = "http://www.kicker.de/news/fussball/bundesliga/spieltag/2-bundesliga/2010-11/spieltag.html"; 
+    } else if (league == "3. Liga") {
+        m_URL = "http://www.kicker.de/news/fussball/3liga/spieltag/3-liga/2010-11/spieltag.html";
     } else if (league == "tipp3 Bundesliga") {
         m_URL = "http://www.kicker.de/news/fussball/intligen/oesterreich/tipp3-bundesliga/2010-11/spieltag.html";
     } else {
